/*
			Unbiased?: 
			Race, Gender, and Sport Effects in 
			University Medical Staff’s Perceptions 
			of Injured Student-Athletes		
***********************************************************************************
NOTE: To be able to run the following commands 
you must use the data base named: acl_unbiased_data.dta
***********************************************************************************/
keep if exclude_resp !=1

****************************
*GENERATE/REPLACE VARIABLES*
****************************
*Race Variables:
egen racen= rowtotal (racial_group*)
gen white= (racial_group1==1 & racen==1)
gen black= (racial_group2==1 & racen==1)
gen asian= (racial_group3==1 & racen==1)
gen hispanic= (racial_group4==1 & racen==1)
gen native= (racial_group5==1 & racen==1)
gen other=  (racial_group6==1 & racen==1)
gen multiracial = (racen>1)

**Target Variables
*0=male, 1=female
gen tgender=.
replace tgender=0 if (school_id==1 | school_id==2 | school_id==5 | school_id==6)
replace tgender=1 if (school_id==3 | school_id==4 | school_id==7 | school_id==8)
label define tgender 1 "female"  0  "male" 
label values tgender tgender
*0=white, 1=black
gen trace=.
replace trace=1 if (school_id==3 | school_id==4 | school_id==5 | school_id==6)
replace trace=0 if (school_id==1 | school_id==2 | school_id==7 | school_id==8)
label define trace 0 "white"  1  "black" 
label values trace trace
*0=bskt, 1=soccer
gen tsport=.
replace tsport=0 if (school_id==1 | school_id==3 | school_id==5 | school_id==7)
replace tsport=1 if (school_id==2 | school_id==4 | school_id==6 | school_id==8)
label define tsport 1 "soccer"  0  "bskt" 
label values tsport tsport

*Overal Demographics 
sum gender white black asian hispanic native other racial_group*, sep (0)

****************************
        *ANOVA*
****************************
*1.Treatment Compliance Expectations
*Scale created from items 
*Likelihood of the student-athlete following medical advice at 5 distinct phases of recovery. rehab_est*
*Likelihood of the student-athlete participating in all prescribed activities. pert_prob
*Likelihood of the student-athlete failing to comply with medical advice at any stage. fail_medical_adv
alpha rehab_est1 rehab_est2 rehab_est3 rehab_est4 pert_prob fail_medical_adv, generate(scale)
anova scale tgender##trace##tsport
*2. Oversight Expectations: 
*a)Amount of oversight student-athlete will need (5-point scale from none to a great deal): Pert-amount
anova pert_amount tgender##trace##tsport
*b) Likelihood of student-athlete needing restrictions (4-point scale from none to a lot): activity_restricted
anova activity_restricted tgender##trace##tsport
*3. Treatment comfort: 	Comfort of respondent in treating the student-athlete: treat
anova treat tgender##trace##tsport
*4. Social support:Likelihood of the student-athlete lacking social support: Prob_lack_ss
anova prob_lack_ss  tgender##trace##tsport



